summaryrefslogtreecommitdiff
path: root/Build/source/texk/lcdf-typetools/include/config.h
diff options
context:
space:
mode:
authorPeter Breitenlohner <peb@mppmu.mpg.de>2011-08-16 15:50:11 +0000
committerPeter Breitenlohner <peb@mppmu.mpg.de>2011-08-16 15:50:11 +0000
commit13a9381f0290f47934524631a29de94501da829b (patch)
treef1c42554e5121c730cc04478e33f63cca0ce041b /Build/source/texk/lcdf-typetools/include/config.h
parentf6d97752a1aef30cc7808f63802cdbdbbed720de (diff)
lcdf-typetools 2.92
git-svn-id: svn://tug.org/texlive/trunk@23575 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Build/source/texk/lcdf-typetools/include/config.h')
-rw-r--r--Build/source/texk/lcdf-typetools/include/config.h14
1 files changed, 10 insertions, 4 deletions
diff --git a/Build/source/texk/lcdf-typetools/include/config.h b/Build/source/texk/lcdf-typetools/include/config.h
index 16831c0a111..90862b448a5 100644
--- a/Build/source/texk/lcdf-typetools/include/config.h
+++ b/Build/source/texk/lcdf-typetools/include/config.h
@@ -11,6 +11,7 @@
# include <win32lib.h>
# endif
#else
+# include <stddef.h>
# define CDECL /* nothing */
#endif
@@ -18,14 +19,19 @@
extern "C" {
#endif
-/* Prototype strerror if we don't have it. */
+/* Prototype strerror if necessary. */
#if !HAVE_STRERROR
char *strerror(int errno);
#endif
-/* Prototype good_strtod if we need it. */
-#if BROKEN_STRTOD
-double good_strtod(const char *nptr, char **endptr);
+/* Prototype strnlen if necessary. */
+#if !HAVE_STRNLEN || !HAVE_DECL_STRNLEN
+size_t strnlen(const char *s, size_t maxlen);
+#endif
+
+/* Prototype good_strtod if necessary. */
+#if HAVE_BROKEN_STRTOD
+double good_strtod(const char *s, char **endptr);
#endif
#ifdef __cplusplus